@@ -3,7 +3,7 @@ use warnings;
 use 5.010;
 package Dist::Zilla::Plugin::OurPkgVersion;
 BEGIN {
-	our $VERSION = 0.1.0;# VERSION
+	our $VERSION = 0.1.1;# VERSION
 }
 use Moose;
 with (
@@ -17,6 +17,13 @@ use PPI;
 use Carp qw(croak);
 use namespace::autoclean;
 
+sub munge_files {
+	my $self = shift;
+	my $_;
+
+	$self->munge_file($_) for @{ $self->found_files };
+}
+
 sub munge_file {
 	my ( $self, $file ) = @_;
 	my $_;
@@ -74,7 +81,7 @@ Dist::Zilla::Plugin::OurPkgVersion - no line insertion and does Package version
 
 =head1 VERSION
 
-version 0.1.0
+version 0.1.1
 
 =head1 SYNOPSIS
 
@@ -157,6 +164,11 @@ VERSION> so it is a bit more work.
 
 =over
 
+=item munge_files
+
+Override the default provided by L<Dist::Zilla::Role::FileMunger> to limit
+the number of files to search to only be modules and executables.
+
 =item munge_file
 
 tells which files to munge, see L<Dist::Zilla::Role::FileMunger>
